@@ -1,5 +1,5 @@
 #######################################################################
-# $Id: LimitPath.pm,v 1.34 2010-11-30 20:20:15 dpchrist Exp $
+# $Id: LimitPath.pm,v 1.35 2010-12-03 05:13:49 dpchrist Exp $
 #######################################################################
 # package:
 #----------------------------------------------------------------------
@@ -21,7 +21,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.34 $=~/: (\d+)\.(\d+)/;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.35 $=~/: (\d+)\.(\d+)/;
 
 #######################################################################
 # uses:
@@ -111,7 +111,7 @@ Dpchrist::File::LimitPath - limit path lengths
 
 =head1 DESCRIPTION
 
-This documentation describes module revision $Revision: 1.34 $.
+This documentation describes module revision $Revision: 1.35 $.
 
 
 This is alpha test level software
@@ -331,8 +331,6 @@ All of the subroutines may be imported by using the ':all' tag:
 
     use Dpchrist::File::LimitPath    qw( :all );
 
-See 'perldoc Export' for everything in between.
-
 		    
 =head1 INSTALLATION
 
@@ -351,13 +349,6 @@ Complete:
 
     $ cpan Bundle::Dpchrist
 
-The following warning may be safely ignored:
-
-    Can't locate Dpchrist/Module/MakefilePL.pm in @INC (@INC contains: /
-    etc/perl /usr/local/lib/perl/5.10.0 /usr/local/share/perl/5.10.0 /us
-    r/lib/perl5 /usr/share/perl5 /usr/lib/perl/5.10 /usr/share/perl/5.10
-    /usr/local/lib/site_perl .) at Makefile.PL line 22.
-
 
 =head2 PREREQUISITES
 
